@@ -29,7 +29,7 @@ static apr_status_t apr_file_transfer_contents(const char *from_path,
     apr_fileperms_t perms;
 
     /* Open source file. */
-    status = apr_file_open(&s, from_path, APR_READ, APR_OS_DEFAULT, pool);
+    status = apr_file_open(&s, from_path, APR_FOPEN_READ, APR_OS_DEFAULT, pool);
     if (status)
         return status;
 
@@ -52,9 +52,15 @@ static apr_status_t apr_file_transfer_contents(const char *from_path,
         return status;
     }
 
+#if BUFSIZ > APR_FILE_DEFAULT_BUFSIZE
+#define COPY_BUFSIZ BUFSIZ
+#else
+#define COPY_BUFSIZ APR_FILE_DEFAULT_BUFSIZE
+#endif
+
     /* Copy bytes till the cows come home. */
     while (1) {
-        char buf[BUFSIZ];
+        char buf[COPY_BUFSIZ];
         apr_size_t bytes_this_time = sizeof(buf);
         apr_status_t read_err;
         apr_status_t write_err;
@@ -95,7 +101,7 @@ APR_DECLARE(apr_status_t) apr_file_copy(const char *from_path,
                                         apr_pool_t *pool)
 {
     return apr_file_transfer_contents(from_path, to_path,
-                                      (APR_WRITE | APR_CREATE | APR_TRUNCATE),
+                                      (APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_TRUNCATE),
                                       perms,
                                       pool);
 }
@@ -106,7 +112,7 @@ APR_DECLARE(apr_status_t) apr_file_append(const char *from_path,
                                           apr_pool_t *pool)
 {
     return apr_file_transfer_contents(from_path, to_path,
-                                      (APR_WRITE | APR_CREATE | APR_APPEND),
+                                      (APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_APPEND),
                                       perms,
                                       pool);
 }
