@@ -157,7 +157,7 @@ void apr__SHA512_Transform(SHA512_CTX*, const sha2_word64*);
 
 /*** SHA-XYZ INITIAL HASH VALUES AND CONSTANTS ************************/
 /* Hash constant words K for SHA-256: */
-const static sha2_word32 K256[64] = {
+static const sha2_word32 K256[64] = {
         0x428a2f98UL, 0x71374491UL, 0xb5c0fbcfUL, 0xe9b5dba5UL,
         0x3956c25bUL, 0x59f111f1UL, 0x923f82a4UL, 0xab1c5ed5UL,
         0xd807aa98UL, 0x12835b01UL, 0x243185beUL, 0x550c7dc3UL,
@@ -177,7 +177,7 @@ const static sha2_word32 K256[64] = {
 };
 
 /* Initial hash value H for SHA-256: */
-const static sha2_word32 sha256_initial_hash_value[8] = {
+static const sha2_word32 sha256_initial_hash_value[8] = {
         0x6a09e667UL,
         0xbb67ae85UL,
         0x3c6ef372UL,
@@ -189,7 +189,7 @@ const static sha2_word32 sha256_initial_hash_value[8] = {
 };
 
 /* Hash constant words K for SHA-384 and SHA-512: */
-const static sha2_word64 K512[80] = {
+static const sha2_word64 K512[80] = {
     APR_UINT64_C(0x428a2f98d728ae22), APR_UINT64_C(0x7137449123ef65cd),
     APR_UINT64_C(0xb5c0fbcfec4d3b2f), APR_UINT64_C(0xe9b5dba58189dbbc),
     APR_UINT64_C(0x3956c25bf348b538), APR_UINT64_C(0x59f111f1b605d019),
@@ -233,7 +233,7 @@ const static sha2_word64 K512[80] = {
 };
 
 /* Initial hash value H for SHA-384 */
-const static sha2_word64 sha384_initial_hash_value[8] = {
+static const sha2_word64 sha384_initial_hash_value[8] = {
     APR_UINT64_C(0xcbbb9d5dc1059ed8),
     APR_UINT64_C(0x629a292a367cd507),
     APR_UINT64_C(0x9159015a3070dd17),
@@ -245,7 +245,7 @@ const static sha2_word64 sha384_initial_hash_value[8] = {
 };
 
 /* Initial hash value H for SHA-512 */
-const static sha2_word64 sha512_initial_hash_value[8] = {
+static const sha2_word64 sha512_initial_hash_value[8] = {
     APR_UINT64_C(0x6a09e667f3bcc908),
     APR_UINT64_C(0xbb67ae8584caa73b),
     APR_UINT64_C(0x3c6ef372fe94f82b),
@@ -557,7 +557,7 @@ void apr__SHA256_Final(sha2_byte digest[], SHA256_CTX* context) {
         }
 
         /* Clean up state data: */
-        MEMSET_BZERO(context, sizeof(context));
+        MEMSET_BZERO(context, sizeof(*context));
         usedspace = 0;
 }
 
@@ -578,7 +578,7 @@ char *apr__SHA256_End(SHA256_CTX* context, char buffer[]) {
                 }
                 *buffer = (char)0;
         } else {
-                MEMSET_BZERO(context, sizeof(context));
+                MEMSET_BZERO(context, sizeof(*context));
         }
         MEMSET_BZERO(digest, SHA256_DIGEST_LENGTH);
         return buffer;
@@ -889,7 +889,7 @@ void apr__SHA512_Final(sha2_byte digest[], SHA512_CTX* context) {
         }
 
         /* Zero out state data */
-        MEMSET_BZERO(context, sizeof(context));
+        MEMSET_BZERO(context, sizeof(*context));
 }
 
 char *apr__SHA512_End(SHA512_CTX* context, char buffer[]) {
@@ -909,7 +909,7 @@ char *apr__SHA512_End(SHA512_CTX* context, char buffer[]) {
                 }
                 *buffer = (char)0;
         } else {
-                MEMSET_BZERO(context, sizeof(context));
+                MEMSET_BZERO(context, sizeof(*context));
         }
         MEMSET_BZERO(digest, SHA512_DIGEST_LENGTH);
         return buffer;
@@ -964,7 +964,7 @@ void apr__SHA384_Final(sha2_byte digest[], SHA384_CTX* context) {
         }
 
         /* Zero out state data */
-        MEMSET_BZERO(context, sizeof(context));
+        MEMSET_BZERO(context, sizeof(*context));
 }
 
 char *apr__SHA384_End(SHA384_CTX* context, char buffer[]) {
@@ -984,7 +984,7 @@ char *apr__SHA384_End(SHA384_CTX* context, char buffer[]) {
                 }
                 *buffer = (char)0;
         } else {
-                MEMSET_BZERO(context, sizeof(context));
+                MEMSET_BZERO(context, sizeof(*context));
         }
         MEMSET_BZERO(digest, SHA384_DIGEST_LENGTH);
         return buffer;
